package com.bweb.controller.item;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.hfkj.common.exception.ErrorCode;
import com.hfkj.common.exception.ErrorHelp;
import com.hfkj.common.exception.SysCode;
import com.hfkj.common.security.UserCenter;
import com.hfkj.common.utils.ResponseMsgUtil;
import com.hfkj.config.MathConfig;
import com.hfkj.entity.EnItem;
import com.hfkj.entity.EnServiceCompanyDevice;
import com.hfkj.model.ResponseData;
import com.hfkj.model.SecUserSessionObject;
import com.hfkj.service.item.EnServiceCompanyDeviceService;
import com.hfkj.sysenum.SecUserObjectTypeEnum;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;

@Controller
@RequestMapping(value="/device")
@Api(value="服务公司设备管理")
public class EnServiceCompanyDeviceController {

    Logger log = LoggerFactory.getLogger(EnServiceCompanyDeviceController.class);
    @Resource
    private UserCenter userCenter;

    @Resource
    private EnServiceCompanyDeviceService enServiceCompanyDeviceService;


    @RequestMapping(value="/create",method = RequestMethod.POST)
    @ResponseBody
    @ApiOperation(value = "创建设备")
    public ResponseData create(@RequestBody EnServiceCompanyDevice body) {
        try {
            if (body == null
                    || body.getDeviceType() == null
                    || StringUtils.isBlank(body.getCredentialsImg())
            ) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
            }
            SecUserSessionObject sessionModel = userCenter.getSessionModel(SecUserSessionObject.class);
            if (sessionModel == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.ACCOUNT_LOGIN_NOT, "");
            }

            if (!sessionModel.getAccount().getObjectType().equals(SecUserObjectTypeEnum.type4.getCode())) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.ROLE_NOT_PERMISSIONS, "");
            }

            body.setUpdateTime(new Date());
            body.setCreateTime(new Date());
            body.setCompanyId(sessionModel.getAccount().getObjectId());
            body.setDeviceNo(MathConfig.generateEncoding(10));
            body.setCreateUser(sessionModel.getAccount().getId());
            body.setStatus(1);
            body.setCreateUserName(sessionModel.getAccount().getUserName());
            enServiceCompanyDeviceService.create(body);

            return ResponseMsgUtil.success("操作成功");

        } catch (Exception e) {
            log.error("error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value="/update",method = RequestMethod.POST)
    @ResponseBody
    @ApiOperation(value = "修改设备")
    public ResponseData update(@RequestBody EnServiceCompanyDevice body) {
        try {
            if (body == null
                    || body.getId() == null
                    || body.getDeviceType() == null
                    || StringUtils.isBlank(body.getCredentialsImg())
            ) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
            }
            SecUserSessionObject sessionModel = userCenter.getSessionModel(SecUserSessionObject.class);
            if (sessionModel == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.ACCOUNT_LOGIN_NOT, "");
            }

            if (!sessionModel.getAccount().getObjectType().equals(SecUserObjectTypeEnum.type4.getCode())) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.ROLE_NOT_PERMISSIONS, "");
            }

            Map<String , Object > map = new HashMap<>();

            map.put("id",body.getId());
            map.put("createUser" , sessionModel.getAccount().getId());

            EnServiceCompanyDevice enServiceCompanyDevice = enServiceCompanyDeviceService.queryDetailByMap(map);
            if (enServiceCompanyDevice == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "服务公司设备不存在");
            }

            enServiceCompanyDevice.setDeviceType(body.getDeviceType());
            enServiceCompanyDevice.setCredentialsImg(body.getCredentialsImg());
            enServiceCompanyDevice.setUpdateTime(new Date());
            enServiceCompanyDevice.setUpdateUser(sessionModel.getAccount().getId());
            enServiceCompanyDevice.setUpdateUserName(sessionModel.getAccount().getUserName());
            enServiceCompanyDeviceService.update(enServiceCompanyDevice);

            return ResponseMsgUtil.success("操作成功");

        } catch (Exception e) {
            log.error("error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }


    @RequestMapping(value="/delete",method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "删除")
    public ResponseData delete(@RequestParam(value = "id" , required = false) Long id) {
        try {

            SecUserSessionObject sessionModel = userCenter.getSessionModel(SecUserSessionObject.class);
            if (sessionModel == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.ACCOUNT_LOGIN_NOT, "");
            }

            Map<String , Object > map = new HashMap<>();

            map.put("id",id);
            map.put("createUser" , sessionModel.getAccount().getId());

            EnServiceCompanyDevice enServiceCompanyDevice = enServiceCompanyDeviceService.queryDetailByMap(map);
            if (enServiceCompanyDevice == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "服务公司设备不存在");
            }

            enServiceCompanyDeviceService.delete(id , false);

            return ResponseMsgUtil.success("删除成功");

        } catch (Exception e) {
            log.error("error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }



    @RequestMapping(value="/queryDetail",method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "查询详情")
    public ResponseData queryDetail(@RequestParam(value = "id" , required = false) Long id) {
        try {

            return ResponseMsgUtil.success(enServiceCompanyDeviceService.queryDetail(id));

        } catch (Exception e) {
            log.error("error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value="/queryList",method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "查询项目列表")
    public ResponseData queryList(@RequestParam(value = "companyId" , required = false) Long companyId,
                                  @RequestParam(value = "deviceNo" , required = false) String deviceNo,
                                  @RequestParam(value = "status" , required = false) Integer status,
                                  @RequestParam(value = "deviceType" , required = false) Integer deviceType,
                                  @RequestParam(value = "pageNum" , required = true) Integer pageNum,
                                  @RequestParam(value = "pageSize" , required = true) Integer pageSize) {
        try {
            SecUserSessionObject sessionModel = userCenter.getSessionModel(SecUserSessionObject.class);
            if (sessionModel == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.ACCOUNT_LOGIN_NOT, "");
            }

            Map<String,Object> param = new HashMap<>();
            param.put("companyId", companyId);
            param.put("deviceNo", deviceNo);
            param.put("deviceType", deviceType);
            param.put("status", status);
            param.put("createUser", sessionModel.getAccount().getId());

            PageHelper.startPage(pageNum, pageSize);
            return ResponseMsgUtil.success(new PageInfo<>(enServiceCompanyDeviceService.getList(param)));

        } catch (Exception e) {
            log.error("error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }
}
