package com.cweb.controller.user;


import com.alibaba.fastjson.JSONObject;
import com.hfkj.common.exception.ErrorCode;
import com.hfkj.common.exception.ErrorHelp;
import com.hfkj.common.exception.SysCode;
import com.hfkj.common.utils.MemberValidateUtil;
import com.hfkj.common.utils.ResponseMsgUtil;
import com.hfkj.model.ResponseData;
import com.hfkj.service.user.BsUserService;
import io.swagger.annotations.Api;

import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.Map;

/**
 * @className: secUser
 * @author: HuRui
 * @date: 2024/3/28
 **/
@Controller
@RequestMapping(value="/user")
@Api(value="客户端")
public class BsUserController {

    Logger log = LoggerFactory.getLogger(BsUserController.class);

    @Resource
    private BsUserService userService;


    @RequestMapping(value = "/phoneNotVerify", method = RequestMethod.POST)
    @ResponseBody
    @ApiOperation(value = "H5手机号不校验登陆")
    public ResponseData phoneNotVerify(@RequestBody JSONObject body) {
        try {
            if (body == null
                    || StringUtils.isBlank(body.getString("phone"))
            ) {
                log.error("LoginController --> phone() error!", "请求参数校验失败");
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
            }
            String phone = body.getString("phone");
            String password = body.getString("password");


            // 校验手机号格式
            if (!MemberValidateUtil.validatePhone(phone)) {
                log.error("LoginController --> phone() error!", "请输入正确的手机号");
                throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "请输入正确的手机号");
            }


            Map<String, Object> other = new HashMap<>();
            return ResponseMsgUtil.success(userService.login(phone, password, other));

        } catch (Exception e) {
            log.error("LoginController --> phone() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }

}
