package com.hfkj.service.item.impl;

import com.hfkj.common.exception.ErrorCode;
import com.hfkj.common.exception.ErrorHelp;
import com.hfkj.common.exception.SysCode;
import com.hfkj.common.utils.MD5Util;
import com.hfkj.dao.EnOilDepotsMapper;
import com.hfkj.entity.EnOilDepots;
import com.hfkj.entity.EnOilDepotsExample;
import com.hfkj.entity.SecUser;
import com.hfkj.service.SecUserService;
import com.hfkj.service.item.EnOilDepotsService;
import com.hfkj.sysenum.SecUserObjectTypeEnum;
import com.hfkj.sysenum.SecUserStatusEnum;
import org.apache.commons.collections4.MapUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.Date;
import java.util.List;
import java.util.Map;

@Service("enOilDepotsService")
public class EnOilDepotsServiceImpl implements EnOilDepotsService {

    @Resource
    private EnOilDepotsMapper enOilDepotsMapper;
    @Resource
    private SecUserService secUserService;

    @Override
    @Transactional(propagation= Propagation.REQUIRES_NEW,rollbackFor= {RuntimeException.class})
    public void create(EnOilDepots enOilDepots) throws Exception {
        enOilDepotsMapper.insert(enOilDepots);

        if (secUserService.getDetailByLoginName(enOilDepots.getContactInfo()) != null) {
            throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "登录账户已存在，请更换");
        }

        SecUser secUser = new SecUser();
        secUser.setUserName(enOilDepots.getOilDepotName());
        secUser.setLoginName(enOilDepots.getContactInfo());
        secUser.setPassword(MD5Util.encode("123456".getBytes()));
        secUser.setTelephone(enOilDepots.getContactInfo());
        secUser.setRoleId(1027L);
        secUser.setObjectType(SecUserObjectTypeEnum.type3.getCode());
        secUser.setObjectId(enOilDepots.getId());
        secUser.setStatus(SecUserStatusEnum.status1.getCode());
        secUserService.editUser(secUser);
    }

    @Override
    public void update(EnOilDepots enOilDepots) {
        enOilDepotsMapper.updateByPrimaryKey(enOilDepots);
        // 查询账户
        SecUser secUser = secUserService.getDetail(SecUserObjectTypeEnum.type3, enOilDepots.getId());
        if (secUser == null) {
            throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "账户数据异常");
        }
        secUser.setUserName(enOilDepots.getOilDepotName());
        secUserService.editUser(secUser);
    }

    @Override
    public void delete(Long id, Boolean fullDelete) {
        EnOilDepots enOilDepots = queryDetail(id);
        if (fullDelete) {
            enOilDepotsMapper.deleteByPrimaryKey(id);
        } else {
            enOilDepots.setStatus(0);
            enOilDepots.setUpdateTime(new Date());
            update(enOilDepots);
        }

        // 查询账户
        SecUser secUser = secUserService.getDetail(SecUserObjectTypeEnum.type3, enOilDepots.getId());
        if (secUser == null) {
            throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "账户数据异常");
        }
        secUser.setStatus(SecUserStatusEnum.status0.getCode());
        secUserService.editUser(secUser);
    }

    @Override
    public EnOilDepots queryDetail(Long id) {
        return enOilDepotsMapper.selectByPrimaryKey(id);
    }

    @Override
    public EnOilDepots queryDetailByMap(Map<String, Object> map) {
        EnOilDepotsExample example = new EnOilDepotsExample();
        EnOilDepotsExample.Criteria criteria = example.createCriteria();

        if (StringUtils.isNotBlank(MapUtils.getString(map, "contactInfo"))) {
            criteria.andContactInfoLike("%"+MapUtils.getString(map, "contactInfo")+"%");
        }
        if (StringUtils.isNotBlank(MapUtils.getString(map, "oilDepotNo"))) {
            criteria.andOilDepotNoLike("%"+MapUtils.getString(map, "oilDepotNo")+"%");
        }
        if (StringUtils.isNotBlank(MapUtils.getString(map, "oilDepotName"))) {
            criteria.andOilDepotNameLike("%"+MapUtils.getString(map, "oilDepotName")+"%");
        }
        if (StringUtils.isNotBlank(MapUtils.getString(map, "contactPerson"))) {
            criteria.andContactPersonLike("%"+MapUtils.getString(map, "contactPerson")+"%");
        }
        if (MapUtils.getLong(map, "itemId") != null) {
            criteria.andItemIdEqualTo(MapUtils.getLong(map, "itemId"));
        }
        if (MapUtils.getLong(map, "createUser") != null) {
            criteria.andCreateUserEqualTo(MapUtils.getLong(map, "createUser"));
        }
        if (MapUtils.getInteger(map, "status") != null) {
            criteria.andStatusEqualTo(MapUtils.getInteger(map, "status"));
        }else {
            criteria.andStatusNotEqualTo(0);
        }
        if (MapUtils.getLong(map , "id") != null) {
            criteria.andIdEqualTo(MapUtils.getLong(map , "id"));
        }

        List<EnOilDepots> list = enOilDepotsMapper.selectByExample(example);

        return list.isEmpty() ? null : list.get(0);
    }

    @Override
    public List<EnOilDepots> getList(Map<String, Object> map) {
        EnOilDepotsExample example = new EnOilDepotsExample();
        EnOilDepotsExample.Criteria criteria = example.createCriteria();

        if (StringUtils.isNotBlank(MapUtils.getString(map, "contactInfo"))) {
            criteria.andContactInfoLike("%"+MapUtils.getString(map, "contactInfo")+"%");
        }
        if (StringUtils.isNotBlank(MapUtils.getString(map, "oilDepotNo"))) {
            criteria.andOilDepotNoLike("%"+MapUtils.getString(map, "oilDepotNo")+"%");
        }
        if (StringUtils.isNotBlank(MapUtils.getString(map, "oilDepotName"))) {
            criteria.andOilDepotNameLike("%"+MapUtils.getString(map, "oilDepotName")+"%");
        }
        if (StringUtils.isNotBlank(MapUtils.getString(map, "contactPerson"))) {
            criteria.andContactPersonLike("%"+MapUtils.getString(map, "contactPerson")+"%");
        }
        if (MapUtils.getLong(map, "itemId") != null) {
            criteria.andItemIdEqualTo(MapUtils.getLong(map, "itemId"));
        }
        if (MapUtils.getLong(map, "createUser") != null) {
            criteria.andCreateUserEqualTo(MapUtils.getLong(map, "createUser"));
        }
        if (MapUtils.getInteger(map, "status") != null) {
            criteria.andStatusEqualTo(MapUtils.getInteger(map, "status"));
        }else {
            criteria.andStatusNotEqualTo(0);
        }

        return enOilDepotsMapper.selectByExample(example);
    }
}
