package com.hfkj.service.item.impl;

import com.hfkj.common.exception.ErrorCode;
import com.hfkj.common.exception.ErrorHelp;
import com.hfkj.common.exception.SysCode;
import com.hfkj.common.utils.MD5Util;
import com.hfkj.dao.EnServiceCompanyMapper;
import com.hfkj.entity.EnServiceCompany;
import com.hfkj.entity.EnServiceCompanyExample;
import com.hfkj.entity.SecUser;
import com.hfkj.service.SecUserService;
import com.hfkj.service.item.EnServiceCompanyService;
import com.hfkj.sysenum.SecUserObjectTypeEnum;
import com.hfkj.sysenum.SecUserStatusEnum;
import org.apache.commons.collections4.MapUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.Date;
import java.util.List;
import java.util.Map;

@Service("enServiceCompanyService")
public class EnServiceCompanyServiceImpl implements EnServiceCompanyService {

    @Resource
    private EnServiceCompanyMapper enServiceCompanyMapper;
    @Resource
    private SecUserService secUserService;

    @Override
    @Transactional(propagation= Propagation.REQUIRES_NEW,rollbackFor= {RuntimeException.class})
    public void create(EnServiceCompany enServiceCompany) throws Exception {
        enServiceCompanyMapper.insert(enServiceCompany);

        if (secUserService.getDetailByLoginName(enServiceCompany.getContactInfo()) != null) {
            throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "登录账户已存在，请更换");
        }

        SecUser secUser = new SecUser();
        secUser.setUserName(enServiceCompany.getName());
        secUser.setLoginName(enServiceCompany.getContactInfo());
        secUser.setPassword(MD5Util.encode("123456".getBytes()));
        secUser.setTelephone(enServiceCompany.getContactInfo());
        secUser.setRoleId(1028L);
        secUser.setObjectType(SecUserObjectTypeEnum.type4.getCode());
        secUser.setObjectId(enServiceCompany.getId());
        secUser.setStatus(SecUserStatusEnum.status1.getCode());
        secUserService.editUser(secUser);
    }

    @Override
    public void update(EnServiceCompany enServiceCompany) {
        enServiceCompanyMapper.updateByPrimaryKey(enServiceCompany);
        // 查询账户
        SecUser secUser = secUserService.getDetail(SecUserObjectTypeEnum.type4, enServiceCompany.getId());
        if (secUser == null) {
            throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "账户数据异常");
        }
        secUser.setUserName(enServiceCompany.getName());
        secUserService.editUser(secUser);
    }

    @Override
    public void delete(Long id, Boolean fullDelete) {
        EnServiceCompany enServiceCompany = queryDetail(id);
        if (fullDelete) {
            enServiceCompanyMapper.deleteByPrimaryKey(id);
        } else {

            enServiceCompany.setStatus(0);
            enServiceCompany.setUpdateTime(new Date());
            update(enServiceCompany);
        }

        // 查询账户
        SecUser secUser = secUserService.getDetail(SecUserObjectTypeEnum.type4, enServiceCompany.getId());
        if (secUser == null) {
            throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "账户数据异常");
        }
        secUser.setStatus(SecUserStatusEnum.status0.getCode());
        secUserService.editUser(secUser);
    }

    @Override
    public EnServiceCompany queryDetail(Long id) {
        return enServiceCompanyMapper.selectByPrimaryKey(id);
    }

    @Override
    public EnServiceCompany queryDetailByMap(Map<String, Object> map) {
        EnServiceCompanyExample example = new EnServiceCompanyExample();
        EnServiceCompanyExample.Criteria criteria = example.createCriteria();

        if (StringUtils.isNotBlank(MapUtils.getString(map, "name"))) {
            criteria.andNameLike("%"+MapUtils.getString(map, "name")+"%");
        }
        if (MapUtils.getLong(map, "createUser") != null) {
            criteria.andCreateUserEqualTo(MapUtils.getLong(map, "createUser"));
        }
        if (StringUtils.isNotBlank(MapUtils.getString(map, "address"))) {
            criteria.andAddressLike("%"+MapUtils.getString(map, "address")+"%");
        }
        if (StringUtils.isNotBlank(MapUtils.getString(map, "person"))) {
            criteria.andPersonLike("%"+MapUtils.getString(map, "person")+"%");
        }
        if (StringUtils.isNotBlank(MapUtils.getString(map, "contactInfo"))) {
            criteria.andContactInfoLike("%"+MapUtils.getString(map, "contactInfo")+"%");
        }
        if (MapUtils.getInteger(map, "status") != null) {
            criteria.andStatusEqualTo(MapUtils.getInteger(map, "status"));
        }else {
            criteria.andStatusNotEqualTo(0);
        }
        if (MapUtils.getLong(map , "id") != null) {
            criteria.andIdEqualTo(MapUtils.getLong(map , "id"));
        }
        List<EnServiceCompany> list = enServiceCompanyMapper.selectByExample(example);

        return list.isEmpty() ? null : list.get(0);
    }

    @Override
    public List<EnServiceCompany> getList(Map<String, Object> map) {
        EnServiceCompanyExample example = new EnServiceCompanyExample();
        EnServiceCompanyExample.Criteria criteria = example.createCriteria();

        if (StringUtils.isNotBlank(MapUtils.getString(map, "name"))) {
            criteria.andNameLike("%"+MapUtils.getString(map, "name")+"%");
        }
        if (StringUtils.isNotBlank(MapUtils.getString(map, "address"))) {
            criteria.andAddressLike("%"+MapUtils.getString(map, "address")+"%");
        }
        if (StringUtils.isNotBlank(MapUtils.getString(map, "person"))) {
            criteria.andPersonLike("%"+MapUtils.getString(map, "person")+"%");
        }
        if (StringUtils.isNotBlank(MapUtils.getString(map, "contactInfo"))) {
            criteria.andContactInfoLike("%"+MapUtils.getString(map, "contactInfo")+"%");
        }
        if (MapUtils.getLong(map, "createUser") != null) {
            criteria.andCreateUserEqualTo(MapUtils.getLong(map, "createUser"));
        }
        if (MapUtils.getInteger(map, "status") != null) {
            criteria.andStatusEqualTo(MapUtils.getInteger(map, "status"));
        }else {
            criteria.andStatusNotEqualTo(0);
        }
        if (MapUtils.getLong(map , "id") != null) {
            criteria.andIdEqualTo(MapUtils.getLong(map , "id"));
        }
        return enServiceCompanyMapper.selectByExample(example);
    }
}
