package com.hfkj.service.item.impl;

import com.hfkj.common.exception.ErrorCode;
import com.hfkj.common.exception.ErrorHelp;
import com.hfkj.common.exception.SysCode;
import com.hfkj.common.utils.MD5Util;
import com.hfkj.dao.EnTransportCompanyMapper;
import com.hfkj.entity.*;
import com.hfkj.service.SecUserService;
import com.hfkj.service.item.EnTransportCompanyService;
import com.hfkj.sysenum.SecUserObjectTypeEnum;
import com.hfkj.sysenum.SecUserStatusEnum;
import org.apache.commons.collections4.MapUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.Collections;
import java.util.Date;
import java.util.List;
import java.util.Map;

@Service("enTransportCompanyService")
public class EnTransportCompanyServiceImpl implements EnTransportCompanyService {

    @Resource
    private EnTransportCompanyMapper enTransportCompanyMapper;
    @Resource
    private SecUserService secUserService;

    @Override
    public void create(EnTransportCompany enTransportCompany) throws Exception {
        enTransportCompanyMapper.insert(enTransportCompany);

        if (secUserService.getDetailByLoginName(enTransportCompany.getContactInfo()) != null) {
            throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "登录账户已存在，请更换");
        }

        SecUser secUser = new SecUser();
        secUser.setUserName(enTransportCompany.getName());
        secUser.setLoginName(enTransportCompany.getContactInfo());
        secUser.setPassword(MD5Util.encode("123456".getBytes()));
        secUser.setTelephone(enTransportCompany.getContactInfo());
        secUser.setRoleId(1029L);
        secUser.setObjectType(SecUserObjectTypeEnum.type5.getCode());
        secUser.setObjectId(enTransportCompany.getId());
        secUser.setStatus(SecUserStatusEnum.status1.getCode());
        secUserService.editUser(secUser);
    }

    @Override
    public void update(EnTransportCompany enTransportCompany) {
        enTransportCompanyMapper.updateByPrimaryKey(enTransportCompany);
        // 查询账户
        SecUser secUser = secUserService.getDetail(SecUserObjectTypeEnum.type5, enTransportCompany.getId());
        if (secUser == null) {
            throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "账户数据异常");
        }
        secUser.setUserName(enTransportCompany.getName());
        secUserService.editUser(secUser);
    }

    @Override
    public void delete(Long id, Boolean fullDelete) {
        EnTransportCompany enTransportCompany = queryDetail(id);
        if (fullDelete) {
            enTransportCompanyMapper.deleteByPrimaryKey(id);
        } else {

            enTransportCompany.setStatus(0);
            enTransportCompany.setUpdateTime(new Date());
            update(enTransportCompany);
        }

        // 查询账户
        SecUser secUser = secUserService.getDetail(SecUserObjectTypeEnum.type5, enTransportCompany.getId());
        if (secUser == null) {
            throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "账户数据异常");
        }
        secUser.setStatus(SecUserStatusEnum.status0.getCode());
        secUserService.editUser(secUser);
    }

    @Override
    public EnTransportCompany queryDetail(Long id) {
        return enTransportCompanyMapper.selectByPrimaryKey(id);
    }

    @Override
    public EnTransportCompany queryDetailByMap(Map<String, Object> map) {
        EnTransportCompanyExample example = new EnTransportCompanyExample();
        EnTransportCompanyExample.Criteria criteria = example.createCriteria();

        if (StringUtils.isNotBlank(MapUtils.getString(map, "name"))) {
            criteria.andNameLike("%"+MapUtils.getString(map, "name")+"%");
        }
        if (MapUtils.getLong(map, "createUser") != null) {
            criteria.andCreateUserEqualTo(MapUtils.getLong(map, "createUser"));
        }
        if (StringUtils.isNotBlank(MapUtils.getString(map, "address"))) {
            criteria.andAddressLike("%"+MapUtils.getString(map, "address")+"%");
        }
        if (StringUtils.isNotBlank(MapUtils.getString(map, "person"))) {
            criteria.andPersonLike("%"+MapUtils.getString(map, "person")+"%");
        }
        if (StringUtils.isNotBlank(MapUtils.getString(map, "contactInfo"))) {
            criteria.andContactInfoLike("%"+MapUtils.getString(map, "contactInfo")+"%");
        }
        if (MapUtils.getInteger(map, "status") != null) {
            criteria.andStatusEqualTo(MapUtils.getInteger(map, "status"));
        }else {
            criteria.andStatusNotEqualTo(0);
        }
        if (MapUtils.getLong(map , "id") != null) {
            criteria.andIdEqualTo(MapUtils.getLong(map , "id"));
        }
        List<EnTransportCompany> list = enTransportCompanyMapper.selectByExample(example);

        return list.isEmpty() ? null : list.get(0);
    }

    @Override
    public List<EnTransportCompany> getList(Map<String, Object> map) {
        EnTransportCompanyExample example = new EnTransportCompanyExample();
        EnTransportCompanyExample.Criteria criteria = example.createCriteria();

        if (StringUtils.isNotBlank(MapUtils.getString(map, "name"))) {
            criteria.andNameLike("%"+MapUtils.getString(map, "name")+"%");
        }
        if (MapUtils.getLong(map, "createUser") != null) {
            criteria.andCreateUserEqualTo(MapUtils.getLong(map, "createUser"));
        }
        if (StringUtils.isNotBlank(MapUtils.getString(map, "address"))) {
            criteria.andAddressLike("%"+MapUtils.getString(map, "address")+"%");
        }
        if (StringUtils.isNotBlank(MapUtils.getString(map, "person"))) {
            criteria.andPersonLike("%"+MapUtils.getString(map, "person")+"%");
        }
        if (StringUtils.isNotBlank(MapUtils.getString(map, "contactInfo"))) {
            criteria.andContactInfoLike("%"+MapUtils.getString(map, "contactInfo")+"%");
        }
        if (MapUtils.getInteger(map, "status") != null) {
            criteria.andStatusEqualTo(MapUtils.getInteger(map, "status"));
        }else {
            criteria.andStatusNotEqualTo(0);
        }
        if (MapUtils.getLong(map , "id") != null) {
            criteria.andIdEqualTo(MapUtils.getLong(map , "id"));
        }
        return enTransportCompanyMapper.selectByExample(example);
    }
}
